@@ -2,16 +2,16 @@
 get_table <- function(filename, table) {
   # Open connection
   thesql <- src_sqlite(filename, create = FALSE)
-  
+
   if (table %in% src_tbls(thesql)) {
-    out <- tbl(thesql, table) %>% collect
+    out <- tbl(thesql, table) %>% collect(n=Inf)
   } else {
     out <- data.frame()
   }
-  
+
   # Close connection
   DBI::dbDisconnect(thesql$con)
-  
+
   # Return result
   out
 }
@@ -20,13 +20,13 @@ get_table <- function(filename, table) {
 get_list_tables <- function(filename) {
   # Open connection
   thesql <- src_sqlite(filename, create = FALSE)
-  
+
   # Read names
   out <- data.frame(tables = src_tbls(thesql))
-  
+
   # Close connection
   DBI::dbDisconnect(thesql$con)
-  
+
   # Return result
   out
 }
@@ -40,7 +40,7 @@ get_list_tables <- function(filename) {
 #' @param sql String containing the SQL query to be performed
 #'
 #' @seealso \code{\link{query_sql}} to perform standard queries of data
-#' 
+#'
 #' @keywords internal
 #' @export
 get_query <- function(filename, sql) {
@@ -56,7 +56,7 @@ get_table_scenario <- function(db, from) {
   # Check inputs
   check_rplexos(db)
   stopifnot(is.character(from), length(from) == 1L)
-  
+
   db %>%
     group_by(scenario, position, filename) %>%
     do(get_table(.$filename, from)) %>%
@@ -73,40 +73,40 @@ get_table_scenario <- function(db, from) {
 #' @seealso \code{\link{plexos_open}} to create the PLEXOS database object
 #' @seealso \code{\link{query_master}} to perform standard queries of data
 #' @family special queries
-#' 
+#'
 #' @examples
 #' # Process the folder with the solution file provided by rplexos
 #' location <- location_solution_rplexos()
 #' process_folder(location)
-#' 
+#'
 #' # Query data
 #' db <- plexos_open(location)
 #' query_sql(db, "SELECT * from day")
 #' query_sql(db, "SELECT * from time")
-#' 
+#'
 #' @export
 query_sql <- function(db, sql) {
   # Check inputs
   check_rplexos(db)
   stopifnot(is.character(sql), length(sql) == 1L)
-  
+
   # Make sure that columns are reported
   db <- db %>%
     group_by(scenario, position, filename)
-  
+
   # Get query data
   if (!is_parallel_rplexos()) {
     out <- db %>%
       do(get_query(.$filename, sql))
   } else {
-    out <- foreach(i = db$position, .combine = rbind_list,
+    out <- foreach(i = db$position, .combine = bind_rows,
                    .packages = c("dplyr", "rplexos", "DBI", "RSQLite")) %dopar% {
       db %>%
         filter(position == i) %>%
         do(get_query(.$filename, sql))
     }
   }
-  
+
   out %>% ungroup
 }
 
@@ -119,16 +119,16 @@ query_sql <- function(db, sql) {
 #' @inheritParams query_master
 #' @seealso \code{\link{plexos_open}} to create the PLEXOS database object
 #' @family special queries
-#' 
+#'
 #' @examples
 #' # Process the folder with the solution file provided by rplexos
 #' location <- location_solution_rplexos()
 #' process_folder(location)
-#' 
+#'
 #' # Query data
 #' db <- plexos_open(location)
 #' query_property(db)
-#' 
+#'
 #' @export
 query_property <- function(db) {
   get_table_scenario(db, "property") %>%
@@ -153,7 +153,7 @@ query_property <- function(db) {
 #' # Process the folder with the solution file provided by rplexos
 #' location <- location_solution_rplexos()
 #' process_folder(location)
-#' 
+#'
 #' # Query data
 #' db <- plexos_open(location)
 #' query_config(db)
@@ -178,12 +178,12 @@ query_config <- function(db) {
 #' # Process the folder with the solution file provided by rplexos
 #' location <- location_solution_rplexos()
 #' process_folder(location)
-#' 
+#'
 #' # Query data
 #' db <- plexos_open(location)
 #' query_log(db)
 #' query_log_steps(db)
-#' 
+#'
 #' @export
 query_log <- function(db) {
   get_table_scenario(db, "log_info") %>%
@@ -200,16 +200,16 @@ query_log_steps <- function(db) {
 # Query databases ***********************************************************************
 
 #' Query data and aggregate data
-#' 
+#'
 #' This collection of functions retrieves data from the processed PLEXOS solutions and
 #' returns it in a convenient format.
-#' 
+#'
 #' The family \code{query_*} returns the raw data in the databases, while \code{sum_*}
 #' aggregates the data according to \code{columns}.
 #'
 #' The functions \code{*_day}, \code{*_week}, \code{*_month} and \code{*_year} are
 #' shortcuts for the corresponding, \code{*_master} function.
-#' 
+#'
 #' The following is a list of valid items for \code{columns} and filtering. Additionally,
 #' \code{time} can be specified for summary data (interval data always includes \code{time}).
 #' \itemize{
@@ -225,30 +225,30 @@ query_log_steps <- function(db) {
 #'   \item{\code{sample}}
 #'   \item{\code{timeslice}}
 #' }
-#' 
+#'
 #' If defined, the \code{filter} parameter must be a \code{list}. The elements must be chracter
 #' vectors and need to have a valid column name (see previous bullet points). For example, one
 #' could define it as follows:
-#' 
+#'
 #' \code{filter = list(name = c("Generator1", "Generator2"), region = "Region1")}
-#' 
+#'
 #' To filter by time use the \code{time.range} parameter, instead of adding it as an entry in the
 #' \code{filter} parameter. For example use \code{c("2015-03-14", "2015-03-15")} in your query.
 #' Please note that the year/month/date starts at midnight (00:00:00).
-#' 
+#'
 #' If a scenario has multiple databases, the data will be aggregated automatically. If two or more
 #' databases within the same scenario have overlapping time periods, the default is to select the
 #' data from the last database (execute \code{summary(db)} so see the order). To change this behavior
 #' set the global option \code{rplexos.tiebreak} to \code{first}, \code{last}, or \code{all} to
 #' select data from the first database, the last one or keep all of them.
-#' 
+#'
 #' Multiple properties can be queried within a collection. If \code{prop} equals the widcard
 #' \code{"*"}, all the properties within a collection are returned.
-#' 
+#'
 #' The parameter \code{multiply.time} allows to multiply values by interval duration (in hours) when
 #' doing the sum of interval data. This can be used, for example, to obtain total energy (in MWh)
 #' from power time series (in MW).
-#' 
+#'
 #' @param db PLEXOS database object
 #' @param time character. Table to query from (interval, day, week, month, year)
 #' @param col character. Collection to query
@@ -259,23 +259,23 @@ query_log_steps <- function(db) {
 #' @param phase integer. PLEXOS optimization phase (1-LT, 2-PASA, 3-MT, 4-ST)
 #' @param multiply.time boolean. When summing interval data, provide the value multiplied by interval duration (See details).
 #' @param ... parameters passed from shortcut functions to master (all except \code{time})
-#' 
+#'
 #' @return A data frame that contains data summarized/aggregated by scenario.
-#' 
+#'
 #' @seealso \code{\link{plexos_open}} to create the PLEXOS database object
 #' @seealso \code{\link{query_sql}} to perform custom queries
-#' 
+#'
 #' @examples
 #' # Process the folder with the solution file provided by rplexos
 #' location <- location_solution_rplexos()
 #' process_folder(location)
-#' 
+#'
 #' # Query data
 #' db <- plexos_open(location)
 #' query_day(db, "Generator", "Generation")
 #' query_day(db, "Region", "*")
 #' query_interval(db, "Generator", "Generation")
-#' 
+#'
 #' @export
 #' @importFrom data.table data.table CJ
 #' @importFrom foreach foreach %dopar%
@@ -292,7 +292,7 @@ query_master <- function(db, time, col, prop, columns = "name", time.range = NUL
     stop("'phase' must be one of: 1 (LT), 2 (PASA), 3 (MT) or 4 (ST)", call. = FALSE)
   if(!all(columns %in% valid_columns()))
     stop("Incorrect column parameter. Use valid_columns() to get the full list.", call. = FALSE)
-  
+
   # Key filter checks
   if (!is.null(filter)) {
     stopifnot(is.list(filter))
@@ -301,36 +301,36 @@ query_master <- function(db, time, col, prop, columns = "name", time.range = NUL
     if(!all(names(filter) %in% valid_columns()))
       stop("The names in 'filter' must correspond to correct columns. Use valid_columns() to get the full list.", call. = FALSE)
   }
-  
+
   # Time range checks
   if (!is.null(time.range)) {
     stopifnot(length(time.range) == 2L)
-    
+
     if (inherits(time.range, "POSIXt")) {
       time.range2 <- time.range
     } else {
       time.range2 <- c(NA, NA)
-      
+
       if (inherits(time.range, "character")) {
         time.range2 <- lubridate::parse_date_time(time.range, c("ymdhms", "ymd"), quiet = TRUE)
       }
-      
+
       if(any(is.na(time.range2)))
         stop("time.range must be POSIXt or character with 'ymdhms' or 'ymd' formats", call. = FALSE)
     }
-    
+
     # Convert dates to ymdhms format, so that queries work correctly
     time.range <- format(time.range2, "%Y-%m-%d %H:%M:%S")
   }
-  
+
   ### BEGIN: Master query checks
-  
+
   # Get list of properties for the collection
   is.summ <- ifelse(identical(time, "interval"), 0, 1)
   is.summ.txt <- ifelse(identical(time, "interval"), "interval", "summary")
-  res <- rbind_all(db$properties) %>%
+  res <- bind_rows(db$properties) %>%
     filter(collection == col, is_summary == is.summ, phase_id == phase)
-  
+
   # Check that collection is valid
   if (nrow(res) == 0L) {
     stop("Collection '", col, "' is not valid for ",
@@ -338,7 +338,7 @@ query_master <- function(db, time, col, prop, columns = "name", time.range = NUL
          "   Use query_property() for list of collections and properties.",
          call. = FALSE)
   }
-  
+
   # Checks if properties are valid
   if (!identical(prop, "*")) {
     invalid.prop <- setdiff(prop, res$property)
@@ -348,12 +348,12 @@ query_master <- function(db, time, col, prop, columns = "name", time.range = NUL
            "   Use query_property() for list of available collections and properties.",
            call. = FALSE)
      }
-    
+
     # Filter properties
     res <- res %>%
       filter(property %in% prop)
   }
-  
+
   # Find if the data is going to have multiple sample, timeslices or bands
   res2 <- res %>%
     ungroup() %>%
@@ -366,41 +366,41 @@ query_master <- function(db, time, col, prop, columns = "name", time.range = NUL
     columns <- c(setdiff(columns, "band"), "band")
   if (res2$is_multi_sample)
     columns <- c(setdiff(columns, "sample"), "sample")
-  
+
   # Columns should not include collection and property; they are always reported
   columns <- setdiff(columns, c("collection", "property"))
-  
+
   # If columns include name, add parent automatically
   if ("name" %in% columns)
     columns <- c("name", "parent", setdiff(columns, c("name", "parent")))
-  
+
   ### END: Master query checks
-  
+
   # Query data for each property
   db2 <- db %>%
     group_by(scenario, position)
-  
+
   if (!is_parallel_rplexos()) {
     out <- db2 %>%
       do(query_master_each(., time, col, prop, columns, time.range, filter, phase))
   } else {
-    out <- foreach(i = db2$position, .combine = rbind_list,
+    out <- foreach(i = db2$position, .combine = bind_rows,
                    .packages = c("dplyr", "rplexos", "DBI", "RSQLite")) %dopar% {
       db2 %>%
         filter(position == i) %>%
         do(query_master_each(., time, col, prop, columns, time.range, filter, phase))
     }
   }
-  
+
   # Ungroup results
   out <- out %>% ungroup
-  
+
   # Return empty dataframe if no results were returned
   if (nrow(out) == 0) {
     warning("Query returned no results", call. = FALSE)
     return(data.frame())
   }
-  
+
   # Check if any scenario is missing from the results
   missing.scenario <- setdiff(unique(db$scenario), unique(out$scenario))
   if (length(missing.scenario) >= 1L) {
@@ -408,11 +408,11 @@ query_master <- function(db, time, col, prop, columns = "name", time.range = NUL
             paste(missing.scenario, collapse = ", "),
             call. = FALSE)
   }
-  
+
   # Solve ties if they exist
   out <- out %>%
     solve_ties()
-  
+
   out
 }
 
@@ -424,13 +424,13 @@ query_master <- function(db, time, col, prop, columns = "name", time.range = NUL
 #' @inheritParams query_master
 #'
 #' @seealso \code{\link{query_master}} to query PLEXOS solutions
-#' 
+#'
 #' @keywords internal
 #' @export
 query_master_each <- function(db, time, col, prop, columns = "name", time.range = NULL, filter = NULL, phase = 4) {
   # Open connection
   thesql <- src_sqlite(db$filename, create = FALSE)
-  
+
   if (!identical(time, "interval")) {
     # Query interval data
     if (identical(prop, "*")) {
@@ -441,13 +441,13 @@ query_master_each <- function(db, time, col, prop, columns = "name", time.range
     } else {
       out <- tbl(thesql, time) %>% filter(property %in% prop)
     }
-    
+
     out <- out %>%
       filter(collection == col, phase_id == phase) %>%
       filter_rplexos(filter) %>%
       filter_rplexos_time(time.range) %>%
       select_rplexos(columns, add.key = FALSE) %>%
-      collect %>%
+      collect(n=Inf) %>%
       mutate(time = lubridate::ymd_hms(time, quiet = TRUE))
   } else {
     # Query interval data
@@ -463,13 +463,13 @@ query_master_each <- function(db, time, col, prop, columns = "name", time.range
       filter(collection == col, phase_id == phase, is_summary == 0) %>%
       select(collection, property, table_name) %>%
       mutate(table_name = gsub("data_interval_", "", table_name))
-    
+
     # If t.name is empty (data is not available), return an empty data frame
     if (nrow(t.name) == 0L) {
       DBI::dbDisconnect(thesql$con)
       return(data.frame())
     }
-    
+
     # Get max/min time existing in the table to be queried
     #   In case time table has more time stamps than those in the dataset
     time.limit <- t.name %>%
@@ -478,28 +478,28 @@ query_master_each <- function(db, time, col, prop, columns = "name", time.range
         tbl(thesql, .$table_name) %>%
           filter(phase_id == phase) %>%
           summarize(time_from = min(time_from), time_to = max(time_to)) %>%
-          collect
+          collect(n=Inf)
       )
     min.time.data <- min(time.limit$time_from)
     max.time.data <- max(time.limit$time_to)
-    
+
     # Collect time data
     time.data <- tbl(thesql, "time") %>%
       filter(phase_id == phase) %>%
       filter(between(time, min.time.data, max.time.data)) %>%
       filter_rplexos_time(time.range) %>%
       select(time) %>%
-      collect
-    
+      collect(n=Inf)
+
     # If time data is empty, return an empty data frame
     if (nrow(time.data) == 0L) {
       DBI::dbDisconnect(thesql$con)
       return(data.frame())
     }
-    
+
     # Convert into R time-data format
     time.data$time <- lubridate::ymd_hms(time.data$time, quiet = TRUE)
-    
+
     # Get interval data
     out1 <- t.name %>%
       group_by(collection, property) %>%
@@ -510,28 +510,28 @@ query_master_each <- function(db, time, col, prop, columns = "name", time.range
            select(-time_to) %>%
            rename(time = time_from) %>%
            select_rplexos(columns, add.key = TRUE) %>%
-           collect
+           collect(n=Inf)
       ) %>%
       ungroup %>%
       mutate(time = lubridate::ymd_hms(time, quiet = TRUE))
-  
+
     # Expand data
     #   This will be easier when dplyr supports rolling joins
     out2 <- data.table(out1, key = "key,time")
     cj2 <- CJ(key = unique(out1$key), time = time.data$time)
-    
+
     out3 <- out2[cj2, roll = TRUE]
     out <- out3 %>%
       as.data.frame(stringsAsFactors = FALSE) %>%
       select(-key)
-    
+
     # Restore time zone
     attributes(out$time) <- attributes(time.data$time)
   }
-  
+
   # Disconnect database
   DBI::dbDisconnect(thesql$con)
-  
+
   # Return value
   return(out)
 }
@@ -546,13 +546,13 @@ solve_ties <- function(x, opt = getOption("rplexos.tiebreak")) {
     warning("Invalid 'rplexos.tiebreak' option (must be one of: first, last, all). Using last instead", call. = FALSE)
     opt <- "last"
   }
-  
+
   if (opt %in% c("first", "last")) {
     # Group by time
     x2 <- x %>%
       ungroup() %>%
       group_by(scenario, time)
-    
+
     if (identical(opt, "last")) {
       # If there are repeats, use the latter entry
       x2 <- x2 %>%
@@ -562,13 +562,13 @@ solve_ties <- function(x, opt = getOption("rplexos.tiebreak")) {
       x2 <- x2 %>%
         filter(position == min(position))
     }
-    
+
     # Ungroup and delete path column
     x2 <- x2 %>%
       ungroup() %>%
       select(-position)
   }
-  
+
   x2
 }
 
@@ -599,14 +599,14 @@ sum_master <- function(db, time, col, prop, columns = "name", time.range = NULL,
 
   # Make sure to include time
   columns2 <- c(setdiff(columns, "time"), "time")
-  
+
   # Run query_master to get the raw data
   out <- query_master(db, time, col, prop, columns2, time.range, filter, phase)
-  
+
   # If empty query is returned, return empty data.frame
   if(nrow(out) == 0L)
     return(data.frame())
-  
+
   if (identical(time, "interval") && (!"time" %in% columns) && multiply.time) {
     # Get length of intervals in hours
     times <- get_table_scenario(db, "time")
@@ -616,13 +616,13 @@ sum_master <- function(db, time, col, prop, columns = "name", time.range = NULL,
       summarize(interval = difftime(lead(time), time, units = "hours") %>%
                   min(na.rm = TRUE) %>%
                   as.numeric)
-    
+
     # Add interval duration to the sum
     out <- out %>%
       inner_join(delta, by = "scenario") %>%
       group_by_char(c("scenario", "collection", "property", columns)) %>%
-      summarise(value = sum(value * interval))  
-    
+      summarise(value = sum(value * interval))
+
     # If unit is a column, modify column
     if ("unit" %in% names(out)) {
       out <- out %>%
@@ -632,9 +632,9 @@ sum_master <- function(db, time, col, prop, columns = "name", time.range = NULL,
     # Sum values
     out <- out %>%
       group_by_char(c("scenario", "collection", "property", columns)) %>%
-      summarise(value = sum(value))  
+      summarise(value = sum(value))
   }
-  
+
   out
 }
 
@@ -667,7 +667,7 @@ filter_rplexos_time <- function(out, time.range, modified = FALSE) {
       out <- filter(out, between(time, time.range[1], time.range[2]))
     }
   }
-  
+
   out
 }
 
@@ -678,14 +678,14 @@ filter_rplexos <- function(out, filt) {
     return(out)
   if (length(filt) == 0L)
     return(out)
-  
+
   # Write the condition as text
   vals <- lapply(filt, function(x)
     paste0("\"", x, "\"", collapse = ", ")) %>%
     paste0("c(", ., ")")
   cons <- ifelse(lapply(filt, length) == 1L, "==", "%in%")
   cond <- paste(names(filt), cons, vals)
-  
+
   # Apply condition
   out %>% filter_(.dots = cond)
 }
@@ -697,10 +697,10 @@ select_rplexos <- function(x, columns, add.key) {
   } else {
     columns.dots <- c("collection", "property", "unit", setdiff(columns, "time"), "time", "value")
   }
-  
+
   columns.dots <- columns.dots %>%
     as.list %>%
     lapply(as.symbol)
-  
+
   select_(x, .dots = columns.dots)
 }
